# Conjunto documentation

Conjunto is an application framework using Django as base. It combines many often used and versatile
django packages and adds common programming patterns to provide  component-based,
plugin-extendable large-scale applications.

Basically, it is a combination of the following packages:

* [HTMX](https://htmx.org)
* [GDAPS plugin framework](https://gdaps.readthedocs.io)
* [Django Web Components](https://pypi.org/project/django-web-components)
* [Tabler.io](https://tabler.io) + [Tabler.io icons](https://tabler.io/icons)
* [Django Tables](https://django-tables2.readthedocs.io)
* [Crispy Forms](https://django-crispy-forms.readthedocs.io)
* [Django extensions](https://django-extensions.readthedocs.io)
* and other things like django-countries, django-markdownify, django-versionfield

It is in an early state of development, so don't expect perfection (yet).